import * as dayjs from "dayjs";
const formatTime = (dateString: Date,format: string ='YYYY-MM-DD HH:mm') => {
  return dayjs(dateString).format(format);
}

// const formatTime2 = (dateString: Date) => {
//   let date = new Date(dateString);
//   const year = date.getFullYear()
//   const month = date.getMonth() + 1
//   const day = date.getDate()
//   const hour = date.getHours()
//   const minute = date.getMinutes()
//   const second = date.getSeconds()
//
//   return (
//     [year, month, day].map(formatNumber).join('-') +
//     ' ' +
//     [hour, minute, second].map(formatNumber).join(':')
//   )
// }
//
// const formatNumber = (n: number) => {
//   const s = n.toString()
//   return s[1] ? s : '0' + s
// }

const to = (promise:Promise<any>)=>{
  return promise.then((res:any)=>{
    return [null,res]
  }).catch((error:any)=>{
    return [error]
  })
}

const getUrl = (url:string,params:string)=>{
  // AppId: app.globalData.AppId
  url = wx.globalData.reqBase + url;
  if(params != null){
    url = url + (url.indexOf('?') >= 0 ? "&" : "?") + params;
  }
  if (wx.globalData.AppId != null && url.indexOf('AppId=') < 0) {
    url = url + (url.indexOf('?') >= 0 ? "&" : "?") + "AppId=" + wx.globalData.AppId;
  }
  if (url.indexOf('wx=3') < 0) {
    url = url + (url.indexOf('?') >= 0 ? "&" : "?")  +'wx=3';
  }
  // if (url.indexOf('FromUserId=') < 0) {
  //   url = url + (url.indexOf('?') >= 0 ? "&" : "?")  +'FromUserId=' + wx.globalData.FromUserId;
  // }

  return url ;
}

const makePhoneCall = (mobile:string)=>{
  wx.pro.showModal({
    title: '提示',
    content: `即将拨打电话 ${mobile}`,
  }).then((res:any) => {
    // on close
    console.log(res);
    if (res.confirm){
      console.log('确认');
      wx.makePhoneCall({
        phoneNumber: mobile,
      })
    }
  });
}

const debounce = (fn:()=>{},delay:number = 200)=>{
  let timer:any = null;
  return function () {
    if (timer) clearTimeout(timer);
    timer = setTimeout(() => {
      // console.log(this);
      if (typeof fn === "function") {
        // @ts-ignore
        fn.apply(this,arguments)
      }
      timer = null;
    }, delay);
  }
}

const  setLoginData = (_this:any)=>{
  let loginData = wx.globalData.loginData;
  console.log('<<<<<<<<<获取loginData',loginData);
  _this.setData({
    loginData,
  })
}

const getSingleUploadImageList = (data:any,type:string)=>{
  let [unid,seq] = data[type].split(";");
  return [{
    url: data[`${type}Url`]||'',
    unid,
    seq
  }]
}

//获取微信定位
const getLocation =  async ()=>{
  let isAuthorize = await getAuthorizeInfo('scope.userLocation');
  if (!isAuthorize) {
    let [error, result] = await wx.$utils.to(wx.pro.authorize({scope: 'scope.userLocation'}));
    if (error){
      console.log(error);
      return false;
    }
    console.log('授权弹窗信息',result);
    // wx.showModal({
    //   title: "提示",
    //   content: "您还未授权定位，请在接下来打开的设置页面开启相册定位！",
    //   success(res) {
    //     if (res.confirm) {
    //       console.log("用户点击确定");
    //       wx.openSetting();
    //     } else if (res.cancel) {
    //       console.log("用户点击取消");
    //     }
    //   },
    // });
    return;
  }
  let [error, result] = await wx.$utils.to(
    wx.pro.getLocation()
  )
  if (error){
    console.log(error);
    return false;
  }
  console.log('获取定位信息',result);
  wx.globalData.location = {
    latitude:result.latitude,
    longitude:result.longitude
  };
  // this.setData({
  //   latitude:result.latitude,
  //   longitude:result.longitude
  // })
  return true;
}

const getAuthorizeInfo = async(scope:string="scope.writePhotosAlbum")=>{
  let [err, res] = await wx.$utils.to(wx.pro.getSetting());
  if (err) {
    return false;
  }
  console.log("getSetting", res);
  return res.authSetting[scope] !== false;
}

// 设置门店名称
const setShopName = (_this:any)=>{
  let settings = wx.globalData.settings;
  console.log('<<<<<<<<<获取settings.name',settings.name);
  _this.setData({
    shopName:settings.name,
    helpUrl:settings.helpUrl,
  })
  wx.setNavigationBarTitle({
    title:settings.name
  })
}

const watchObj = (target:object,callback:Function)=>{
  let handler = {
    get(target:object, key:string, receiver:any) {
      console.log('>>>>>>...get', key)
      return Reflect.get(target, key, receiver)
      //等价于 return target[key];
    },
    set(target:object, key:string, value:any, receiver:any) {
      console.log('>>>>>...set', key, value);
      typeof callback === 'function' && callback(key, value)
      return Reflect.set(target, key, value, receiver)
      //等价于 return target[key] = value;
    }
  }
  return new Proxy(target, handler)

}

const scrollToError = (selector:string, errorMsg:string, duration:number = 3000)=>{
  wx.pageScrollTo({
    selector,
    duration: 300
  })
  wx.showToast({
    title: errorMsg,
    icon: 'none',
    duration
  })
}
export default{
  formatTime,
  to,
  getUrl,
  makePhoneCall,
  debounce,
  setLoginData,
  getSingleUploadImageList,
  getLocation,
  getAuthorizeInfo,
  setShopName,
  watchObj,
  scrollToError
}
